from oslo_config import cfg

GROUP = 'celery'

CONF = cfg.CONF
CONF.register_opt(cfg.StrOpt('broker_url'), group=GROUP)
CONF.register_opt(cfg.StrOpt('result_backend'), group=GROUP)
CONF.register_opt(cfg.StrOpt('task_serializer'), group=GROUP)
CONF.register_opt(cfg.StrOpt('result_serializer'), group=GROUP)



import base

from celery import signature


class AsyncAction(base.BaseAction):

    def run(self, context):
        signature(self.task_name, kwargs=self.params).delay()

    def is_sync(self):
        return False



from mistral_lib.actions import base
from celery import Celery, signature
from oslo_config import cfg

CONF = cfg.CONF

celery_settings = {
    'BROKER_URL': CONF.celery.broker_url,
    'CELERY_RESULT_BACKEND': CONF.celery.result_backend,
    'CELERY_TASK_SERIALIZER': CONF.celery.task_serializer,
    'CELERY_RESULT_SERIALIZER': CONF.celery.result_serializer
}


class CeleryConfig(object):
    def __init__(self):
        self.celery_app = Celery()
        self.celery_app.config_from_object(celery_settings)


class BaseAction(CeleryConfig, base.Action):
    def __init__(self, task_name, params):
        super(BaseAction, self).__init__()
        self.task_name = task_name
        self.params = params

    def run(self, context):
        result = signature(self.task_name, kwargs=self.params).delay()
        return result.get()



#!/usr/bin/env python

import os
from setuptools import setup


with open('requirements.txt') as f:
    required = f.read().splitlines()

setup(
    setup_requires=['pbr'],
    package_dir={'': '.'},
    py_modules=['celery_actions'],
    pbr=True,
    description='Mistral actions to execute Celery tasks',
    version='1.0.0',
    author='Collabo Team',
    download_url='https://github.com/collabo-br/mistral-celery-actions/archive/1.0.0.tar.gz',
    keywords=['workflow', 'actions', 'mistral', 'celery'],
    install_requires=required
)
